"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.jsonParse = exports.deepCopy = void 0;
const deepCopy = (source) => {
    let clone;
    let i;
    const hasOwnProp = Object.prototype.hasOwnProperty.bind(source);
    if (typeof source !== 'object' || source === null) {
        return source;
    }
    if (source instanceof Date) {
        return new Date(source.getTime());
    }
    if (Array.isArray(source)) {
        clone = [];
        const len = source.length;
        for (i = 0; i < len; i++) {
            clone[i] = (0, exports.deepCopy)(source[i]);
        }
        return clone;
    }
    clone = {};
    for (i in source) {
        if (hasOwnProp(i)) {
            clone[i] = (0, exports.deepCopy)(source[i]);
        }
    }
    return clone;
};
exports.deepCopy = deepCopy;
const jsonParse = (jsonString, options) => {
    try {
        return JSON.parse(jsonString);
    }
    catch (error) {
        if ((options === null || options === void 0 ? void 0 : options.fallbackValue) !== undefined) {
            return options.fallbackValue;
        }
        else if (options === null || options === void 0 ? void 0 : options.errorMessage) {
            throw new Error(options.errorMessage);
        }
        throw error;
    }
};
exports.jsonParse = jsonParse;
//# sourceMappingURL=utils.js.map